==> eam-wshub-proxyclient-11.4-5-sources.jar: net/datastream/schemas/mp_fields/ASPECTTOLERANCEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour ASPECTTOLERANCEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="ASPECTTOLERANCEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOLERANCECODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASPECTCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ASPECTTOLERANCEID_Type", propOrder = {
    "tolerancecode",
    "aspectcode",
    "organizationid"
})
public class ASPECTTOLERANCEID_Type {

    @XmlElement(name = "TOLERANCECODE", required = true)
    protected String tolerancecode;
    @XmlElement(name = "ASPECTCODE")
    protected String aspectcode;
    @XmlElement(name = "ORGANIZATIONID")
    protected ORGANIZATIONID_Type organizationid;

    /**
     * Obtient la valeur de la propriété tolerancecode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTOLERANCECODE() {
        return tolerancecode;
    }

    /**
     * Définit la valeur de la propriété tolerancecode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTOLERANCECODE(String value) {
        this.tolerancecode = value;
    }

    /**
     * Obtient la valeur de la propriété aspectcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getASPECTCODE() {
        return aspectcode;
    }

    /**
     * Définit la valeur de la propriété aspectcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setASPECTCODE(String value) {
        this.aspectcode = value;
    }

    /**
     * Obtient la valeur de la propriété organizationid.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Définit la valeur de la propriété organizationid.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/ASPECTTOLERANCEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ASPECTTOLERANCEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ASPECTTOLERANCEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOLERANCECODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASPECTCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ASPECTTOLERANCEID_Type", propOrder = {
    "tolerancecode",
    "aspectcode",
    "organizationid"
})
public class ASPECTTOLERANCEID_Type {

    @XmlElement(name = "TOLERANCECODE", required = true)
    protected String tolerancecode;
    @XmlElement(name = "ASPECTCODE")
    protected String aspectcode;
    @XmlElement(name = "ORGANIZATIONID")
    protected ORGANIZATIONID_Type organizationid;

    /**
     * Gets the value of the tolerancecode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTOLERANCECODE() {
        return tolerancecode;
    }

    /**
     * Sets the value of the tolerancecode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTOLERANCECODE(String value) {
        this.tolerancecode = value;
    }

    /**
     * Gets the value of the aspectcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getASPECTCODE() {
        return aspectcode;
    }

    /**
     * Sets the value of the aspectcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setASPECTCODE(String value) {
        this.aspectcode = value;
    }

    /**
     * Gets the value of the organizationid property.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Sets the value of the organizationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

}
